Struct Saadc
pub struct Saadc { /* private fields */ }Expand description
Analog to Digital Converter 0.
Implementations
impl Saadc
impl Saadc
pub const unsafe fn from_ptr(ptr: *mut ()) -> Saadc
pub const fn as_ptr(&self) -> *mut ()
pub const fn tasks_start(self) -> Reg<u32, W>
pub const fn tasks_start(self) -> Reg<u32, W>
Start the ADC and prepare the result buffer in RAM.
pub const fn tasks_sample(self) -> Reg<u32, W>
pub const fn tasks_sample(self) -> Reg<u32, W>
Take one ADC sample, if scan is enabled all channels are sampled.
pub const fn tasks_stop(self) -> Reg<u32, W>
pub const fn tasks_stop(self) -> Reg<u32, W>
Stop the ADC and terminate any ongoing conversion.
pub const fn tasks_calibrateoffset(self) -> Reg<u32, W>
pub const fn tasks_calibrateoffset(self) -> Reg<u32, W>
Starts offset auto-calibration.
pub const fn subscribe_start(self) -> Reg<Subscribe, RW>
pub const fn subscribe_start(self) -> Reg<Subscribe, RW>
Subscribe configuration for task START.
pub const fn subscribe_sample(self) -> Reg<Subscribe, RW>
pub const fn subscribe_sample(self) -> Reg<Subscribe, RW>
Subscribe configuration for task SAMPLE.
pub const fn subscribe_stop(self) -> Reg<Subscribe, RW>
pub const fn subscribe_stop(self) -> Reg<Subscribe, RW>
Subscribe configuration for task STOP.
pub const fn subscribe_calibrateoffset(self) -> Reg<Subscribe, RW>
pub const fn subscribe_calibrateoffset(self) -> Reg<Subscribe, RW>
Subscribe configuration for task CALIBRATEOFFSET.
pub const fn events_started(self) -> Reg<u32, RW>
pub const fn events_started(self) -> Reg<u32, RW>
The ADC has started.
pub const fn events_end(self) -> Reg<u32, RW>
pub const fn events_end(self) -> Reg<u32, RW>
The ADC has filled up the Result buffer.
pub const fn events_done(self) -> Reg<u32, RW>
pub const fn events_done(self) -> Reg<u32, RW>
A conversion task has been completed. Depending on the mode, multiple conversions might be needed for a result to be transferred to RAM.
pub const fn events_resultdone(self) -> Reg<u32, RW>
pub const fn events_resultdone(self) -> Reg<u32, RW>
A result is ready to get transferred to RAM.
pub const fn events_calibratedone(self) -> Reg<u32, RW>
pub const fn events_calibratedone(self) -> Reg<u32, RW>
Calibration is complete.
pub const fn events_stopped(self) -> Reg<u32, RW>
pub const fn events_stopped(self) -> Reg<u32, RW>
The ADC has stopped.
pub const fn publish_started(self) -> Reg<Publish, RW>
pub const fn publish_started(self) -> Reg<Publish, RW>
Publish configuration for event STARTED.
pub const fn publish_end(self) -> Reg<Publish, RW>
pub const fn publish_end(self) -> Reg<Publish, RW>
Publish configuration for event END.
pub const fn publish_done(self) -> Reg<Publish, RW>
pub const fn publish_done(self) -> Reg<Publish, RW>
Publish configuration for event DONE.
pub const fn publish_resultdone(self) -> Reg<Publish, RW>
pub const fn publish_resultdone(self) -> Reg<Publish, RW>
Publish configuration for event RESULTDONE.
pub const fn publish_calibratedone(self) -> Reg<Publish, RW>
pub const fn publish_calibratedone(self) -> Reg<Publish, RW>
Publish configuration for event CALIBRATEDONE.
pub const fn publish_stopped(self) -> Reg<Publish, RW>
pub const fn publish_stopped(self) -> Reg<Publish, RW>
Publish configuration for event STOPPED.
pub const fn publish_ch(self, n: usize) -> PublishCh
pub const fn publish_ch(self, n: usize) -> PublishCh
Publish configuration for events.
pub const fn resolution(self) -> Reg<Resolution, RW>
pub const fn resolution(self) -> Reg<Resolution, RW>
Resolution configuration.
pub const fn oversample(self) -> Reg<Oversample, RW>
pub const fn oversample(self) -> Reg<Oversample, RW>
Oversampling configuration. OVERSAMPLE should not be combined with SCAN. The RESOLUTION is applied before averaging, thus for high OVERSAMPLE a higher RESOLUTION should be used.
pub const fn samplerate(self) -> Reg<Samplerate, RW>
pub const fn samplerate(self) -> Reg<Samplerate, RW>
Controls normal or continuous sample rate.